# Generated by roxygen2: do not edit by hand

S3method("$",ba)
S3method("$",rmcorr)
S3method("$",skipped_corr)
S3method("$",summary.corr_result)
S3method("[[",ba)
S3method("[[",rmcorr)
S3method("[[",skipped_corr)
S3method("[[",summary.corr_result)
S3method(as.data.frame,corr_edge_list)
S3method(ci,ba)
S3method(ci,ba_matrix)
S3method(ci,ba_repeated)
S3method(ci,ba_repeated_matrix)
S3method(ci,ccc)
S3method(ci,ccc_ci)
S3method(ci,ccc_glmm)
S3method(ci,cia)
S3method(ci,cia_ci)
S3method(ci,cia_rm)
S3method(ci,cohen_kappa)
S3method(ci,corr_result)
S3method(ci,default)
S3method(ci,gwet_ac)
S3method(ci,icc)
S3method(ci,icc_overall)
S3method(ci,icc_rm_reml)
S3method(ci,krippendorff_alpha)
S3method(ci,multirater_kappa)
S3method(ci,partial_corr)
S3method(ci,prob_agree)
S3method(ci,rmcorr)
S3method(ci,rmcorr_matrix)
S3method(ci,weighted_kappa)
S3method(coef,ccc_glmm)
S3method(coef,corr_result)
S3method(confint,ba)
S3method(confint,ba_matrix)
S3method(confint,ba_repeated)
S3method(confint,ba_repeated_matrix)
S3method(confint,ccc)
S3method(confint,ccc_ci)
S3method(confint,ccc_glmm)
S3method(confint,chatterjee_xi_scalar)
S3method(confint,cia)
S3method(confint,cia_ci)
S3method(confint,cia_rm)
S3method(confint,cohen_kappa)
S3method(confint,corr_result)
S3method(confint,gwet_ac)
S3method(confint,icc)
S3method(confint,icc_overall)
S3method(confint,icc_rm_reml)
S3method(confint,krippendorff_alpha)
S3method(confint,multirater_kappa)
S3method(confint,partial_corr)
S3method(confint,prob_agree)
S3method(confint,rmcorr)
S3method(confint,rmcorr_matrix)
S3method(confint,summary.corr_result)
S3method(confint,summary.matrixCorr)
S3method(confint,weighted_kappa)
S3method(estimate,ba)
S3method(estimate,ba_matrix)
S3method(estimate,ba_repeated)
S3method(estimate,ba_repeated_matrix)
S3method(estimate,ccc_glmm)
S3method(estimate,corr_result)
S3method(estimate,default)
S3method(estimate,partial_corr)
S3method(estimate,summary.corr_result)
S3method(estimate,summary.matrixCorr)
S3method(names,ba)
S3method(names,rmcorr)
S3method(names,skipped_corr)
S3method(plot,ba)
S3method(plot,ba_matrix)
S3method(plot,ba_repeated)
S3method(plot,ba_repeated_matrix)
S3method(plot,bicor)
S3method(plot,biserial_corr)
S3method(plot,ccc)
S3method(plot,cia)
S3method(plot,cia_rm)
S3method(plot,cohen_kappa)
S3method(plot,corr_edge_list)
S3method(plot,corr_matrix)
S3method(plot,corr_sparse)
S3method(plot,dcor)
S3method(plot,dgCMatrix)
S3method(plot,dsCMatrix)
S3method(plot,gwet_ac)
S3method(plot,hsic)
S3method(plot,kendall_matrix)
S3method(plot,krippendorff_alpha)
S3method(plot,multirater_kappa)
S3method(plot,partial_corr)
S3method(plot,pbcor)
S3method(plot,pearson_corr)
S3method(plot,polychoric_corr)
S3method(plot,polyserial_corr)
S3method(plot,prob_agree)
S3method(plot,rmcorr)
S3method(plot,rmcorr_matrix)
S3method(plot,robust_dcor)
S3method(plot,schafer_corr)
S3method(plot,shrinkage_corr)
S3method(plot,skipped_corr)
S3method(plot,sparseMatrix)
S3method(plot,spearman_rho)
S3method(plot,tetrachoric_corr)
S3method(plot,wincor)
S3method(print,ba)
S3method(print,ba_matrix)
S3method(print,ba_repeated)
S3method(print,ba_repeated_matrix)
S3method(print,bicor)
S3method(print,biserial_corr)
S3method(print,ccc)
S3method(print,ccc_ci)
S3method(print,ccc_glmm)
S3method(print,chatterjee_xi)
S3method(print,chatterjee_xi_scalar)
S3method(print,cia)
S3method(print,cia_ci)
S3method(print,cia_rm)
S3method(print,cohen_kappa)
S3method(print,corr_edge_list)
S3method(print,dcor)
S3method(print,gwet_ac)
S3method(print,hsic)
S3method(print,icc)
S3method(print,icc_overall)
S3method(print,icc_rm_reml)
S3method(print,kendall_matrix)
S3method(print,krippendorff_alpha)
S3method(print,matrixCorr_ccc)
S3method(print,matrixCorr_ccc_ci)
S3method(print,multirater_kappa)
S3method(print,partial_corr)
S3method(print,pbcor)
S3method(print,pearson_corr)
S3method(print,polychoric_corr)
S3method(print,polyserial_corr)
S3method(print,prob_agree)
S3method(print,rmcorr)
S3method(print,rmcorr_matrix)
S3method(print,robust_dcor)
S3method(print,schafer_corr)
S3method(print,shrinkage_corr)
S3method(print,skipped_corr)
S3method(print,spearman_rho)
S3method(print,summary.ba)
S3method(print,summary.ba_matrix)
S3method(print,summary.ba_repeated)
S3method(print,summary.ba_repeated_matrix)
S3method(print,summary.bicor)
S3method(print,summary.biserial_corr)
S3method(print,summary.ccc)
S3method(print,summary.ccc_glmm)
S3method(print,summary.ccc_rm_reml)
S3method(print,summary.chatterjee_xi_scalar)
S3method(print,summary.cia)
S3method(print,summary.cia_rm)
S3method(print,summary.cohen_kappa)
S3method(print,summary.corr_matrix)
S3method(print,summary.corr_result)
S3method(print,summary.dcor)
S3method(print,summary.gwet_ac)
S3method(print,summary.hsic)
S3method(print,summary.icc)
S3method(print,summary.icc_overall)
S3method(print,summary.icc_rm_reml)
S3method(print,summary.kendall_matrix)
S3method(print,summary.krippendorff_alpha)
S3method(print,summary.latent_corr)
S3method(print,summary.matrixCorr)
S3method(print,summary.multirater_kappa)
S3method(print,summary.partial_corr)
S3method(print,summary.pbcor)
S3method(print,summary.pearson_corr)
S3method(print,summary.polychoric_corr)
S3method(print,summary.polyserial_corr)
S3method(print,summary.prob_agree)
S3method(print,summary.rmcorr)
S3method(print,summary.rmcorr_matrix)
S3method(print,summary.skipped_corr)
S3method(print,summary.spearman_rho)
S3method(print,summary.tetrachoric_corr)
S3method(print,summary.wincor)
S3method(print,tetrachoric_corr)
S3method(print,weighted_kappa)
S3method(print,wincor)
S3method(summary,ba)
S3method(summary,ba_matrix)
S3method(summary,ba_repeated)
S3method(summary,ba_repeated_matrix)
S3method(summary,bicor)
S3method(summary,biserial_corr)
S3method(summary,ccc)
S3method(summary,ccc_glmm)
S3method(summary,ccc_rm_reml)
S3method(summary,chatterjee_xi_scalar)
S3method(summary,cia)
S3method(summary,cia_rm)
S3method(summary,cohen_kappa)
S3method(summary,corr_edge_list)
S3method(summary,corr_matrix)
S3method(summary,corr_sparse)
S3method(summary,dcor)
S3method(summary,dgCMatrix)
S3method(summary,dsCMatrix)
S3method(summary,gwet_ac)
S3method(summary,hsic)
S3method(summary,icc)
S3method(summary,icc_overall)
S3method(summary,icc_rm_reml)
S3method(summary,kendall_matrix)
S3method(summary,krippendorff_alpha)
S3method(summary,multirater_kappa)
S3method(summary,partial_corr)
S3method(summary,pbcor)
S3method(summary,pearson_corr)
S3method(summary,polychoric_corr)
S3method(summary,polyserial_corr)
S3method(summary,prob_agree)
S3method(summary,rmcorr)
S3method(summary,rmcorr_matrix)
S3method(summary,robust_dcor)
S3method(summary,schafer_corr)
S3method(summary,shrinkage_corr)
S3method(summary,skipped_corr)
S3method(summary,sparseMatrix)
S3method(summary,spearman_rho)
S3method(summary,tetrachoric_corr)
S3method(summary,wincor)
S3method(tidy,ba)
S3method(tidy,ba_matrix)
S3method(tidy,ba_repeated)
S3method(tidy,ba_repeated_matrix)
S3method(tidy,corr_result)
S3method(tidy,default)
S3method(tidy,partial_corr)
S3method(tidy,summary.corr_result)
S3method(tidy,summary.matrixCorr)
export(ba)
export(ba_rm)
export(bicor)
export(biserial)
export(biweight_mid_corr)
export(bland_altman)
export(bland_altman_repeated)
export(ccc)
export(ccc_glmm)
export(ccc_lmm_reml)
export(ccc_pairwise_u_stat)
export(ccc_rm_reml)
export(ccc_rm_ustat)
export(ci)
export(cia)
export(cia_rm)
export(cohen_kappa)
export(dcor)
export(diag.bicor)
export(distance_corr)
export(estimate)
export(gwet_ac)
export(hsic)
export(icc)
export(icc_rm_reml)
export(kendall_tau)
export(krippendorff_alpha)
export(multirater_kappa)
export(partial_correlation)
export(pbcor)
export(pcorr)
export(pearson_corr)
export(polychoric)
export(polyserial)
export(prob_agree)
export(rmcorr)
export(rmcorr_weighted)
export(robust_dcor)
export(schafer_corr)
export(shrinkage_corr)
export(skipped_corr)
export(skipped_corr_masks)
export(spearman_rho)
export(tetrachoric)
export(tidy)
export(view_corr_shiny)
export(view_rmcorr_shiny)
export(weighted_kappa)
export(wincor)
export(xi_corr)
import(ggplot2)
importFrom(Matrix,Matrix)
importFrom(Rcpp,evalCpp)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(generics,tidy)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,rect)
importFrom(rlang,.data)
importFrom(rlang,arg_match)
importFrom(rlang,is_bool)
importFrom(rlang,is_scalar_character)
importFrom(rlang,is_scalar_integerish)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,hclust)
importFrom(stats,model.matrix)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,plogis)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,capture.output)
useDynLib(matrixCorr, .registration = TRUE)
