% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{compute_ci_from_se}
\alias{compute_ci_from_se}
\title{compute_ci_from_se}
\usage{
compute_ci_from_se(ccc, se, level)
}
\description{
Compute confidence intervals from point estimate and standard error.
}
\keyword{internal}
