% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_scalar_character}
\alias{check_scalar_character}
\title{Check scalar character (non-empty)}
\usage{
check_scalar_character(
  x,
  arg = as.character(substitute(x)),
  allow_empty = FALSE
)
}
\description{
Check scalar character (non-empty)
}
\keyword{internal}
