% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.mc_abort_condition}
\alias{.mc_abort_condition}
\title{Rethrow a caught condition as a cli error}
\usage{
.mc_abort_condition(cnd, .class = character())
}
\description{
Rethrow a caught condition as a cli error
}
\keyword{internal}
