% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corr_result_s3.R
\name{plot.corr_edge_list}
\alias{plot.corr_edge_list}
\title{S3 Plot for Edge-List Correlation Results}
\usage{
\method{plot}{corr_edge_list}(
  x,
  title = NULL,
  low_color = "indianred1",
  high_color = "steelblue1",
  mid_color = "white",
  value_text_size = 4,
  ci_text_size = 3,
  show_value = TRUE,
  ...
)
}
\arguments{
\item{x}{An edge-list correlation result.}

\item{title}{Optional plot title.}

\item{low_color}{Fill color for -1.}

\item{high_color}{Fill color for +1.}

\item{mid_color}{Fill color for 0.}

\item{value_text_size}{Text size for optional overlaid values.}

\item{ci_text_size}{Text size for optional confidence-interval labels.}

\item{show_value}{Logical; overlay values if \code{TRUE}.}

\item{...}{Additional theme arguments.}
}
\description{
S3 Plot for Edge-List Correlation Results
}
