% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{build_LDZ}
\alias{build_LDZ}
\title{build_LDZ}
\usage{
build_LDZ(
  colnames_X,
  method_levels,
  time_levels,
  Dsub,
  df_sub,
  method_name,
  time_name,
  slope,
  interaction,
  slope_var,
  drop_zero_cols
)
}
\description{
Internal helper to construct L, Dm, and Z matrices for random effects.
}
\keyword{internal}
