% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_weights}
\alias{check_weights}
\title{Check weights vector (non-negative, finite, correct length)}
\usage{
check_weights(w, n, arg = as.character(substitute(w)))
}
\description{
Check weights vector (non-negative, finite, correct length)
}
\keyword{internal}
