% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_scalar_nonneg}
\alias{check_scalar_nonneg}
\title{Check a non-negative scalar (>= 0)}
\usage{
check_scalar_nonneg(x, arg = as.character(substitute(x)), strict = FALSE)
}
\description{
Check a non-negative scalar (>= 0)
}
\keyword{internal}
