% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_scalar_int_pos}
\alias{check_scalar_int_pos}
\title{Check strictly positive scalar integer}
\usage{
check_scalar_int_pos(x, arg = as.character(substitute(x)))
}
\description{
Check strictly positive scalar integer
}
\keyword{internal}
