% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_required_cols}
\alias{check_required_cols}
\title{Check that a data frame contains required columns}
\usage{
check_required_cols(df, cols, df_arg = "data")
}
\description{
Check that a data frame contains required columns
}
\keyword{internal}
