% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/latent_corr.R
\name{print.summary.latent_corr}
\alias{print.summary.latent_corr}
\title{Summary Method for Latent Correlation Matrices}
\usage{
\method{print}{summary.latent_corr}(x, digits = 4, ...)
}
\arguments{
\item{x}{An object of class \code{summary.latent_corr}.}

\item{digits}{Integer; number of decimal places to print.}

\item{...}{Unused.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Prints compact summary statistics returned by
\code{summary.tetrachoric_corr()}, \code{summary.polychoric_corr()},
\code{summary.polyserial_corr()}, and \code{summary.biserial_corr()}.
}
