% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{run_cpp}
\alias{run_cpp}
\title{run_cpp}
\usage{
run_cpp(
  Xr,
  yr,
  subject,
  method_int,
  time_int,
  Laux,
  Z,
  use_ar1,
  ar1_rho,
  max_iter,
  tol,
  conf_level,
  ci_mode_int,
  include_subj_method = TRUE,
  include_subj_time = TRUE,
  sb_zero_tol = 1e-10,
  eval_single_visit = FALSE,
  time_weights = NULL,
  metric_mode = 0L,
  loglik_only = FALSE,
  need_reml_loglik = TRUE
)
}
\description{
Wrapper for calling 'C++' backend for CCC estimation.
}
\keyword{internal}
