% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{match_arg}
\alias{match_arg}
\title{Match argument to allowed values}
\usage{
match_arg(arg, values, arg_name = as.character(substitute(arg)))
}
\description{
Match argument to allowed values
}
\keyword{internal}
