% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{abort_bad_arg}
\alias{abort_bad_arg}
\title{Abort with a standardised argument error}
\usage{
abort_bad_arg(arg, message, ..., .hint = NULL, .class = character())
}
\description{
Abort with a standardised argument error
}
\keyword{internal}
