% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_symmetric_matrix}
\alias{check_symmetric_matrix}
\title{Check matrix symmetry}
\usage{
check_symmetric_matrix(
  M,
  tol = .Machine$double.eps^0.5,
  arg = as.character(substitute(M))
)
}
\description{
Check matrix symmetry
}
\keyword{internal}
