% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_same_length}
\alias{check_same_length}
\title{Check that two vectors have the same length}
\usage{
check_same_length(
  x,
  y,
  arg_x = as.character(substitute(x)),
  arg_y = as.character(substitute(y))
)
}
\description{
Check that two vectors have the same length
}
\keyword{internal}
