% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{.vc_message}
\alias{.vc_message}
\title{.vc_message}
\usage{
.vc_message(
  ans,
  label,
  nm,
  nt,
  conf_level,
  digits = 4,
  use_message = TRUE,
  extra_label = NULL,
  ar = c("none", "ar1"),
  ar_rho = NA_real_,
  engine_name = "ccc_rm_reml",
  se_label = "SE(CCC)"
)
}
\description{
Display variance component estimation details to the console.
}
\keyword{internal}
