% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{estimate_rho}
\alias{estimate_rho}
\title{estimate_rho}
\usage{
estimate_rho(
  Xr,
  yr,
  subject,
  method_int,
  time_int,
  Laux,
  Z,
  rho_lo = -0.95,
  rho_hi = 0.95,
  max_iter = 100,
  tol = 1e-06,
  conf_level = 0.95,
  ci_mode_int,
  include_subj_method = TRUE,
  include_subj_time = TRUE,
  sb_zero_tol = 1e-10,
  eval_single_visit = FALSE,
  time_weights = NULL,
  metric_mode = 0L
)
}
\description{
Estimate AR(1) correlation parameter rho by optimizing REML log-likelihood.
}
\keyword{internal}
