% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corr_result_s3.R
\name{$.summary.corr_result}
\alias{$.summary.corr_result}
\title{Summary Accessor for Correlation Summaries}
\usage{
\method{$}{summary.corr_result}(x, name)
}
\arguments{
\item{x}{A \code{summary.corr_result} object.}

\item{name}{A column name or summary metadata key.}
}
\value{
A summary column (if present) or summary metadata entry.
}
\description{
Summary Accessor for Correlation Summaries
}
