% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corr_result_s3.R
\name{print.summary.corr_result}
\alias{print.summary.corr_result}
\title{Print Standardized Correlation Summaries}
\usage{
\method{print}{summary.corr_result}(
  x,
  digits = 4,
  n = NULL,
  topn = NULL,
  max_vars = NULL,
  width = NULL,
  show_ci = NULL,
  ...
)
}
\arguments{
\item{x}{A \code{summary.corr_result} object.}

\item{digits}{Number of digits for numeric values.}

\item{n}{Optional preview row threshold.}

\item{topn}{Optional number of head/tail rows when preview is truncated.}

\item{max_vars}{Optional maximum number of visible columns in preview.}

\item{width}{Optional output width.}

\item{show_ci}{One of \code{"yes"} or \code{"no"}.}

\item{...}{Unused.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Print Standardized Correlation Summaries
}
