% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_inherits}
\alias{check_inherits}
\title{Check object class}
\usage{
check_inherits(x, class, arg = as.character(substitute(x)))
}
\description{
Check object class
}
\keyword{internal}
