% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{ccc_lmm_reml_pairwise}
\alias{ccc_lmm_reml_pairwise}
\title{ccc_lmm_reml_pairwise}
\usage{
ccc_lmm_reml_pairwise(
  df,
  fml,
  response,
  rind,
  method,
  time,
  slope,
  slope_var,
  slope_Z,
  drop_zero_cols,
  Dmat,
  ar,
  ar_rho,
  max_iter,
  tol,
  conf_level,
  verbose,
  digits,
  use_message,
  extra_label,
  ci,
  ci_mode_int,
  all_time_lvls,
  Dmat_type = c("time-avg", "typical-visit", "weighted-avg", "weighted-sq"),
  Dmat_weights = NULL,
  Dmat_rescale = TRUE,
  vc_select = c("auto", "none"),
  vc_alpha = 0.05,
  vc_test_order = c("subj_time", "subj_method"),
  include_subj_method = NULL,
  include_subj_time = NULL,
  sb_zero_tol = 1e-10,
  metric_mode = 0L,
  estimate_key = "ccc",
  se_key = "se_ccc",
  out_class = "ccc_rm_reml",
  out_method = "Variance Components REML - pairwise",
  out_description = "Lin's CCC per method pair from random-effects LMM",
  summary_title = "Repeated-measures concordance matrix",
  vc_engine_name = "ccc_rm_reml",
  vc_se_label = "SE(CCC)"
)
}
\description{
Internal function to handle pairwise CCC estimation for each method pair.
}
\keyword{internal}
