% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_prob_scalar}
\alias{check_prob_scalar}
\title{Check probability in unit interval}
\usage{
check_prob_scalar(x, arg = as.character(substitute(x)), open_ends = FALSE)
}
\description{
Check probability in unit interval
}
\keyword{internal}
