% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{estimate}
\alias{estimate}
\alias{tidy}
\alias{ci}
\alias{estimate.corr_result}
\alias{estimate.summary.corr_result}
\alias{estimate.summary.matrixCorr}
\alias{coef.corr_result}
\alias{ci.corr_result}
\alias{ci.default}
\alias{ci.ba}
\alias{ci.ba_matrix}
\alias{ci.ba_repeated}
\alias{ci.ba_repeated_matrix}
\alias{ci.ccc}
\alias{ci.ccc_ci}
\alias{ci.ccc_glmm}
\alias{ci.cia}
\alias{ci.cia_ci}
\alias{ci.cia_rm}
\alias{ci.cohen_kappa}
\alias{ci.gwet_ac}
\alias{ci.icc}
\alias{ci.icc_overall}
\alias{ci.icc_rm_reml}
\alias{ci.krippendorff_alpha}
\alias{ci.multirater_kappa}
\alias{ci.partial_corr}
\alias{ci.prob_agree}
\alias{ci.rmcorr}
\alias{ci.rmcorr_matrix}
\alias{ci.weighted_kappa}
\alias{estimate.partial_corr}
\alias{estimate.ba}
\alias{estimate.ba_matrix}
\alias{estimate.ba_repeated}
\alias{estimate.ba_repeated_matrix}
\alias{estimate.ccc_glmm}
\alias{coef.ccc_glmm}
\alias{estimate.default}
\alias{tidy.corr_result}
\alias{tidy.summary.corr_result}
\alias{tidy.summary.matrixCorr}
\alias{tidy.partial_corr}
\alias{tidy.ba}
\alias{tidy.ba_matrix}
\alias{tidy.ba_repeated}
\alias{tidy.ba_repeated_matrix}
\alias{tidy.default}
\alias{confint.corr_result}
\alias{confint.summary.corr_result}
\alias{confint.summary.matrixCorr}
\alias{confint.ba}
\alias{confint.ba_repeated}
\alias{confint.ba_matrix}
\alias{confint.ba_repeated_matrix}
\alias{confint.ccc}
\alias{confint.ccc_ci}
\alias{confint.ccc_glmm}
\alias{confint.chatterjee_xi_scalar}
\alias{confint.cia}
\alias{confint.cia_ci}
\alias{confint.cia_rm}
\alias{confint.cohen_kappa}
\alias{confint.gwet_ac}
\alias{confint.icc}
\alias{confint.icc_overall}
\alias{confint.icc_rm_reml}
\alias{confint.krippendorff_alpha}
\alias{confint.multirater_kappa}
\alias{confint.prob_agree}
\alias{confint.partial_corr}
\alias{confint.rmcorr}
\alias{confint.rmcorr_matrix}
\alias{confint.weighted_kappa}
\title{Access MatrixCorr Estimates, Confidence Intervals, and Tidy Results}
\usage{
estimate(x, ...)

tidy(x, ...)

ci(x, ...)

\method{estimate}{corr_result}(x, ...)

\method{estimate}{summary.corr_result}(x, ...)

\method{estimate}{summary.matrixCorr}(x, ...)

\method{coef}{corr_result}(object, ...)

\method{ci}{corr_result}(x, ...)

\method{ci}{default}(x, ...)

\method{ci}{ba}(x, ...)

\method{ci}{ba_matrix}(x, ...)

\method{ci}{ba_repeated}(x, ...)

\method{ci}{ba_repeated_matrix}(x, ...)

\method{ci}{ccc}(x, ...)

\method{ci}{ccc_ci}(x, ...)

\method{ci}{ccc_glmm}(x, ...)

\method{ci}{cia}(x, ...)

\method{ci}{cia_ci}(x, ...)

\method{ci}{cia_rm}(x, ...)

\method{ci}{cohen_kappa}(x, ...)

\method{ci}{gwet_ac}(x, ...)

\method{ci}{icc}(x, ...)

\method{ci}{icc_overall}(x, ...)

\method{ci}{icc_rm_reml}(x, ...)

\method{ci}{krippendorff_alpha}(x, ...)

\method{ci}{multirater_kappa}(x, ...)

\method{ci}{partial_corr}(x, ...)

\method{ci}{prob_agree}(x, ...)

\method{ci}{rmcorr}(x, ...)

\method{ci}{rmcorr_matrix}(x, ...)

\method{ci}{weighted_kappa}(x, ...)

\method{estimate}{partial_corr}(x, ...)

\method{estimate}{ba}(x, ...)

\method{estimate}{ba_matrix}(x, ...)

\method{estimate}{ba_repeated}(x, ...)

\method{estimate}{ba_repeated_matrix}(x, ...)

\method{estimate}{ccc_glmm}(x, ...)

\method{coef}{ccc_glmm}(object, ...)

\method{estimate}{default}(x, ...)

\method{tidy}{corr_result}(x, diag = FALSE, triangle = c("upper", "lower", "full"), ...)

\method{tidy}{summary.corr_result}(x, ...)

\method{tidy}{summary.matrixCorr}(x, ...)

\method{tidy}{partial_corr}(x, diag = FALSE, triangle = c("upper", "lower", "full"), ...)

\method{tidy}{ba}(x, ...)

\method{tidy}{ba_matrix}(x, ...)

\method{tidy}{ba_repeated}(x, ...)

\method{tidy}{ba_repeated_matrix}(x, ...)

\method{tidy}{default}(x, diag = FALSE, triangle = c("upper", "lower", "full"), ...)

\method{confint}{corr_result}(object, parm, level = NULL, ...)

\method{confint}{summary.corr_result}(object, parm, level = NULL, ...)

\method{confint}{summary.matrixCorr}(object, parm, level = NULL, ...)

\method{confint}{ba}(object, parm, level = NULL, ...)

\method{confint}{ba_repeated}(object, parm, level = NULL, ...)

\method{confint}{ba_matrix}(object, parm, level = NULL, ...)

\method{confint}{ba_repeated_matrix}(object, parm, level = NULL, ...)

\method{confint}{ccc}(object, parm, level = NULL, ...)

\method{confint}{ccc_ci}(object, parm, level = NULL, ...)

\method{confint}{ccc_glmm}(object, parm, level = NULL, ...)

\method{confint}{chatterjee_xi_scalar}(object, parm, level = NULL, ...)

\method{confint}{cia}(object, parm, level = NULL, ...)

\method{confint}{cia_ci}(object, parm, level = NULL, ...)

\method{confint}{cia_rm}(object, parm, level = NULL, ...)

\method{confint}{cohen_kappa}(object, parm, level = NULL, ...)

\method{confint}{gwet_ac}(object, parm, level = NULL, ...)

\method{confint}{icc}(object, parm, level = NULL, ...)

\method{confint}{icc_overall}(object, parm, level = NULL, ...)

\method{confint}{icc_rm_reml}(object, parm, level = NULL, ...)

\method{confint}{krippendorff_alpha}(object, parm, level = NULL, ...)

\method{confint}{multirater_kappa}(object, parm, level = NULL, ...)

\method{confint}{prob_agree}(object, parm, level = NULL, ...)

\method{confint}{partial_corr}(object, parm, level = NULL, ...)

\method{confint}{rmcorr}(object, parm, level = NULL, ...)

\method{confint}{rmcorr_matrix}(object, parm, level = NULL, ...)

\method{confint}{weighted_kappa}(object, parm, level = NULL, ...)
}
\arguments{
\item{x, object}{A matrixCorr result, summary object, or scalar result.}

\item{...}{Additional arguments passed to methods.}

\item{diag}{Logical; include diagonal entries for matrix-style results.
Default is \code{FALSE}.}

\item{triangle}{For matrix-style correlation results, which triangle to
return from \code{tidy()}: \code{"upper"} (default), \code{"lower"}, or
\code{"full"}. The default avoids duplicate pairs for symmetric matrices;
directed matrices use all off-diagonal entries unless \code{triangle} is
supplied explicitly.}

\item{parm}{Ignored; included for compatibility with \code{stats::confint()}.}

\item{level}{Confidence level requested by \code{stats::confint()}. MatrixCorr
objects store pre-computed intervals; if \code{level} differs from the
stored level, recompute the original object with the desired level.}
}
\value{
\code{estimate()} returns the primary estimate in its natural shape: a
matrix-like result returns a matrix, an edge-list result returns a data frame,
and a scalar result returns a numeric value.

\code{tidy()} returns a data frame with columns such as \code{item1},
\code{item2}, \code{estimate}, \code{lwr}, \code{upr}, diagnostics, and
inferential quantities when available.

\code{confint()} returns a data frame containing confidence limits when they
are available.

\code{ci()} returns the stored confidence-interval payload. It is mainly a
structured alternative to reading \code{attr(x, "ci")} directly.
}
\description{
Lightweight accessors for matrixCorr result objects. These functions do not
change the stored object structure; they just provide a stable way to extract the
estimate matrix, confidence intervals, or a pairwise data frame without
reading attributes directly.
}
\examples{
X <- cbind(a = 1:10, b = 1:10 + rnorm(10), c = rnorm(10))
fit <- pearson_corr(X, ci = TRUE)

estimate(fit)
tidy(fit)
ci(fit)
confint(fit)

}
\author{
Thiago de Paula Oliveira
}
