% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ba_rm.R
\name{.ba_rep_two_methods}
\alias{.ba_rep_two_methods}
\title{two-method helper}
\usage{
.ba_rep_two_methods(
  response,
  subject,
  method12,
  time,
  loa_multiplier,
  conf_level,
  n_threads,
  include_slope,
  use_ar1,
  ar1_rho,
  max_iter,
  tol
)
}
\description{
two-method helper
}
\keyword{internal}
