% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{num_or_na_vec}
\alias{num_or_na_vec}
\title{num_or_na_vec}
\usage{
num_or_na_vec(x)
}
\description{
Display variance component estimation details to the console.
}
\keyword{internal}
