% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{num_or_na}
\alias{num_or_na}
\title{num_or_na}
\usage{
num_or_na(x)
}
\description{
Helper to safely coerce a value to numeric or return NA if invalid.
}
\keyword{internal}
