% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_scalar_numeric}
\alias{check_scalar_numeric}
\title{Check scalar numeric (with optional bounds)}
\usage{
check_scalar_numeric(
  x,
  arg = as.character(substitute(x)),
  finite = TRUE,
  lower = -Inf,
  upper = Inf,
  allow_na = FALSE,
  closed_lower = TRUE,
  closed_upper = TRUE
)
}
\description{
Check scalar numeric (with optional bounds)
}
\keyword{internal}
