% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_bool}
\alias{check_bool}
\title{Check a single logical flag}
\usage{
check_bool(x, arg = as.character(substitute(x)))
}
\description{
Check a single logical flag
}
\keyword{internal}
