% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_ar1_rho}
\alias{check_ar1_rho}
\title{Check AR(1) correlation parameter}
\usage{
check_ar1_rho(x, arg = as.character(substitute(x)), bound = 0.999)
}
\description{
Check AR(1) correlation parameter
}
\keyword{internal}
