% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_matrix_dims}
\alias{check_matrix_dims}
\title{Check matrix dimensions}
\usage{
check_matrix_dims(
  M,
  nrow = NULL,
  ncol = NULL,
  arg = as.character(substitute(M))
)
}
\description{
Check matrix dimensions
}
\keyword{internal}
