% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{abort_internal}
\alias{abort_internal}
\title{Abort for internal errors (should not happen)}
\usage{
abort_internal(message, ..., .class = character())
}
\description{
Abort for internal errors (should not happen)
}
\keyword{internal}
