% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{print.matrixCorr_ccc_ci}
\alias{print.matrixCorr_ccc_ci}
\title{Print method for matrixCorr CCC objects with CIs}
\usage{
\method{print}{matrixCorr_ccc_ci}(x, ...)
}
\arguments{
\item{x}{A \code{matrixCorr_ccc} or \code{matrixCorr_ccc_ci} object.}

\item{...}{Passed to underlying printers.}
}
\description{
Print method for matrixCorr CCC objects with CIs
}
