% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{inform_if_verbose}
\alias{inform_if_verbose}
\title{Inform only when verbose}
\usage{
inform_if_verbose(
  ...,
  .verbose = getOption("matrixCorr.verbose", TRUE),
  .envir = parent.frame()
)
}
\description{
Inform only when verbose
}
\keyword{internal}
