% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corr_result_s3.R
\name{as.data.frame.corr_edge_list}
\alias{as.data.frame.corr_edge_list}
\title{Edge-list data-frame view}
\usage{
\method{as.data.frame}{corr_edge_list}(x, row.names = NULL, optional = FALSE, ...)
}
\arguments{
\item{x}{A \code{corr_edge_list} object.}

\item{row.names}{Ignored.}

\item{optional}{Ignored.}

\item{...}{Unused.}
}
\value{
A data frame with columns \code{row}, \code{col}, \code{value}.
}
\description{
Edge-list data-frame view
}
