% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ccc_repeated.R
\name{.align_weights_to_levels}
\alias{.align_weights_to_levels}
\title{Align (optional named) weights to a subset of time levels}
\usage{
.align_weights_to_levels(w, present_lvls, all_lvls)
}
\description{
Align (optional named) weights to a subset of time levels
}
\keyword{internal}
